@@ -19,7 +19,7 @@ class Exec:
         self.driver.implicitly_wait(10)
         if not os.path.isdir(f'screenshot/case{case_idx}'):
             os.makedirs(f'screenshot/case{case_idx}')
-            case_idx+=1
+
 
 
 
@@ -31,7 +31,7 @@ class Exec:
                 with allure.step(f'步骤{step}:{step_text}'):
                     self.driver.get(goto_data)
                     log.info(f'步骤{step}:{step_text}')
-                    file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name,'rb') as f:
                         file = f.read()
@@ -52,7 +52,7 @@ class Exec:
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'定位方式by={input_ele[:-1][0]},定位的值{input_ele[:-1][-1]}')
                     log.info(f'输入的值{input_ele[-1]}')
-                    file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
@@ -70,7 +70,7 @@ class Exec:
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'定位方式by={click_data[0]},定位的值{click_data[-1]}')
                     log.info('点击元素')
-                    file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
@@ -93,19 +93,22 @@ class Exec:
                             if isinstance(result,list):
                                 log.info(f'步骤{step}:{step_text}')
                                 log.info(f'期望值{assert_data[0]},实际值{result}')
+                                case_idx += 1
                                 assert assert_data[0] in result
                             else:
                                 log.info(f'步骤{step}:{step_text}')
                                 log.info(f'期望值{assert_data[0]},实际值{result}')
+                                case_idx += 1
                                 assert assert_data[0] == result
                         except Exception as error:
                             log.info(f'步骤{step}:{step_text}')
                             log.error(f'断言失败，期望值{assert_data[0]},实际值{result}')
-                            file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}断言失败.png'
+                            file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}断言失败.png'
                             self.driver.save_screenshot(file_name)
                             with open(file_name, 'rb') as f:
                                 file = f.read()
                             allure.attach(file, attachment_type=allure.attachment_type.PNG)
+                            case_idx += 1
                             raise error
                     else:
                         log.info(f'没有找到变量{assert_data[-1]}')
@@ -123,7 +126,7 @@ class Exec:
                     var = text_ele[-1]
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'保存变量{var},变量值为{text_msg}')
-                    file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
@@ -141,7 +144,7 @@ class Exec:
                     var = text_ele[-1]
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'保存变量{var},变量值为{text_msg}')
-                    file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/case{case_idx}/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
