@@ -17,7 +17,7 @@ all_data = get_excel_data(filepath,filesheet)
 @allure.epic(f'{all_data[1]}')
 @allure.feature(f'{filesheet}')
 @allure.title('{data[1][name]}')
-def test_tem(data):
+def test_temp(data):
         exe = Exec(data)
         list_dict = {
             'goto':exe.goto,
